
edam-ontology.py
-------------------

EDAM is licensed under a Creative Commons Attribution-ShareAlike 4.0 International License (CC BY-SA 4.0) and
can be found at http://edamontology.org/.

EDAM is described in the following article. If you use, or refer to EDAM or its part, please cite:

    Ison, J., Kalaš, M., Jonassen, I., Bolser, D., Uludag, M., McWilliam, H., Malone, J., Lopez, R., Pettifer, S. and Rice, P. (2013). EDAM: an ontology of bioinformatics operations, types of data and identifiers, topics and formats. Bioinformatics, 29(10): 1325-1332. DOI: 10.1093/bioinformatics/btt113 PMID: 23479348 The article is freely available without restrictions (Open access)

This project is just a Python packaged version of that data - initially developed to avoid non-Python dependencies
within Galaxy packages that need to leverage the ontology.
